---
title: aws_dynamodb
type: cache
status: stable
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/cache/aws_dynamodb.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';


Stores key/value pairs as a single document in a DynamoDB table. The key is
stored as a string value and used as the table hash key. The value is stored as
a binary value using the `data_key` field name.

Introduced in version 3.36.0.


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yaml
# Common config fields, showing default values
label: ""
aws_dynamodb:
  table: ""
  hash_key: ""
  data_key: ""
  region: eu-west-1
```

</TabItem>
<TabItem value="advanced">

```yaml
# All config fields, showing default values
label: ""
aws_dynamodb:
  table: ""
  hash_key: ""
  data_key: ""
  consistent_read: false
  ttl: ""
  ttl_key: ""
  region: eu-west-1
  endpoint: ""
  credentials:
    profile: ""
    id: ""
    secret: ""
    token: ""
    role: ""
    role_external_id: ""
  max_retries: 3
  backoff:
    initial_interval: 1s
    max_interval: 5s
    max_elapsed_time: 30s
```

</TabItem>
</Tabs>

A prefix can be specified to allow multiple cache types to share a single
DynamoDB table. An optional TTL duration (`ttl`) and field
(`ttl_key`) can be specified if the backing table has TTL enabled.

Strong read consistency can be enabled using the `consistent_read`
configuration field.

### Credentials

By default Benthos will use a shared credentials file when connecting to AWS
services. It's also possible to set them explicitly at the component level,
allowing you to transfer data across accounts. You can find out more
[in this document](/docs/guides/aws).

## Fields

### `table`

The table to store items in.


Type: `string`  
Default: `""`  

### `hash_key`

The key of the table column to store item keys within.


Type: `string`  
Default: `""`  

### `data_key`

The key of the table column to store item values within.


Type: `string`  
Default: `""`  

### `consistent_read`

Whether to use strongly consistent reads on Get commands.


Type: `bool`  
Default: `false`  

### `ttl`

An optional TTL to set for items, calculated from the moment the item is cached.


Type: `string`  
Default: `""`  

### `ttl_key`

The column key to place the TTL value within.


Type: `string`  
Default: `""`  

### `region`

The AWS region to target.


Type: `string`  
Default: `"eu-west-1"`  

### `endpoint`

Allows you to specify a custom endpoint for the AWS API.


Type: `string`  
Default: `""`  

### `credentials`

Optional manual configuration of AWS credentials to use. More information can be found [in this document](/docs/guides/aws).


Type: `object`  

### `credentials.profile`

A profile from `~/.aws/credentials` to use.


Type: `string`  
Default: `""`  

### `credentials.id`

The ID of credentials to use.


Type: `string`  
Default: `""`  

### `credentials.secret`

The secret for the credentials being used.


Type: `string`  
Default: `""`  

### `credentials.token`

The token for the credentials being used, required when using short term credentials.


Type: `string`  
Default: `""`  

### `credentials.role`

A role ARN to assume.


Type: `string`  
Default: `""`  

### `credentials.role_external_id`

An external ID to provide when assuming a role.


Type: `string`  
Default: `""`  

### `max_retries`

The maximum number of retries before giving up on the request. If set to zero there is no discrete limit.


Type: `int`  
Default: `3`  

### `backoff`

Control time intervals between retry attempts.


Type: `object`  

### `backoff.initial_interval`

The initial period to wait between retry attempts.


Type: `string`  
Default: `"1s"`  

### `backoff.max_interval`

The maximum period to wait between retry attempts.


Type: `string`  
Default: `"5s"`  

### `backoff.max_elapsed_time`

The maximum period to wait before retry attempts are abandoned. If zero then no limit is used.


Type: `string`  
Default: `"30s"`  


